@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -268,14 +268,13 @@ class FirestoreAdminAsyncClient:
         metadata for the operation will be the type
         [IndexOperationMetadata][google.firestore.admin.v1.IndexOperationMetadata].
 
-
         .. code-block:: python
 
             from google.cloud import firestore_admin_v1
 
-            def sample_create_index():
+            async def sample_create_index():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_admin_v1.CreateIndexRequest(
@@ -287,7 +286,7 @@ class FirestoreAdminAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -358,7 +357,12 @@ class FirestoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -386,9 +390,9 @@ class FirestoreAdminAsyncClient:
 
             from google.cloud import firestore_admin_v1
 
-            def sample_list_indexes():
+            async def sample_list_indexes():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_admin_v1.ListIndexesRequest(
@@ -399,7 +403,7 @@ class FirestoreAdminAsyncClient:
                 page_result = client.list_indexes(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -471,12 +475,20 @@ class FirestoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListIndexesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -497,9 +509,9 @@ class FirestoreAdminAsyncClient:
 
             from google.cloud import firestore_admin_v1
 
-            def sample_get_index():
+            async def sample_get_index():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_admin_v1.GetIndexRequest(
@@ -507,7 +519,7 @@ class FirestoreAdminAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_index(request=request)
+                response = await client.get_index(request=request)
 
                 # Handle the response
                 print(response)
@@ -579,7 +591,12 @@ class FirestoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -599,9 +616,9 @@ class FirestoreAdminAsyncClient:
 
             from google.cloud import firestore_admin_v1
 
-            def sample_delete_index():
+            async def sample_delete_index():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_admin_v1.DeleteIndexRequest(
@@ -609,7 +626,7 @@ class FirestoreAdminAsyncClient:
                 )
 
                 # Make the request
-                client.delete_index(request=request)
+                await client.delete_index(request=request)
 
         Args:
             request (Union[google.cloud.firestore_admin_v1.types.DeleteIndexRequest, dict]):
@@ -672,7 +689,10 @@ class FirestoreAdminAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def get_field(
@@ -690,9 +710,9 @@ class FirestoreAdminAsyncClient:
 
             from google.cloud import firestore_admin_v1
 
-            def sample_get_field():
+            async def sample_get_field():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_admin_v1.GetFieldRequest(
@@ -700,7 +720,7 @@ class FirestoreAdminAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_field(request=request)
+                response = await client.get_field(request=request)
 
                 # Handle the response
                 print(response)
@@ -774,7 +794,12 @@ class FirestoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -805,14 +830,13 @@ class FirestoreAdminAsyncClient:
         the special ``Field`` with resource name:
         ``projects/{project_id}/databases/{database_id}/collectionGroups/__default__/fields/*``.
 
-
         .. code-block:: python
 
             from google.cloud import firestore_admin_v1
 
-            def sample_update_field():
+            async def sample_update_field():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 field = firestore_admin_v1.Field()
@@ -827,7 +851,7 @@ class FirestoreAdminAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -894,7 +918,12 @@ class FirestoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -926,14 +955,13 @@ class FirestoreAdminAsyncClient:
         with the filter set to ``indexConfig.usesAncestorConfig:false``
         .
 
-
         .. code-block:: python
 
             from google.cloud import firestore_admin_v1
 
-            def sample_list_fields():
+            async def sample_list_fields():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_admin_v1.ListFieldsRequest(
@@ -944,7 +972,7 @@ class FirestoreAdminAsyncClient:
                 page_result = client.list_fields(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1016,12 +1044,20 @@ class FirestoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListFieldsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1051,14 +1087,13 @@ class FirestoreAdminAsyncClient:
         refer to:
         https://cloud.google.com/firestore/docs/manage-data/export-import
 
-
         .. code-block:: python
 
             from google.cloud import firestore_admin_v1
 
-            def sample_export_documents():
+            async def sample_export_documents():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_admin_v1.ExportDocumentsRequest(
@@ -1070,7 +1105,7 @@ class FirestoreAdminAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1135,7 +1170,12 @@ class FirestoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1165,14 +1205,13 @@ class FirestoreAdminAsyncClient:
         cancelled, it is possible that a subset of the data has
         already been imported to Cloud Firestore.
 
-
         .. code-block:: python
 
             from google.cloud import firestore_admin_v1
 
-            def sample_import_documents():
+            async def sample_import_documents():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_admin_v1.ImportDocumentsRequest(
@@ -1184,7 +1223,7 @@ class FirestoreAdminAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1257,7 +1296,12 @@ class FirestoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1285,9 +1329,9 @@ class FirestoreAdminAsyncClient:
 
             from google.cloud import firestore_admin_v1
 
-            def sample_get_database():
+            async def sample_get_database():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_admin_v1.GetDatabaseRequest(
@@ -1295,7 +1339,7 @@ class FirestoreAdminAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_database(request=request)
+                response = await client.get_database(request=request)
 
                 # Handle the response
                 print(response)
@@ -1357,7 +1401,12 @@ class FirestoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1377,9 +1426,9 @@ class FirestoreAdminAsyncClient:
 
             from google.cloud import firestore_admin_v1
 
-            def sample_list_databases():
+            async def sample_list_databases():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_admin_v1.ListDatabasesRequest(
@@ -1387,7 +1436,7 @@ class FirestoreAdminAsyncClient:
                 )
 
                 # Make the request
-                response = client.list_databases(request=request)
+                response = await client.list_databases(request=request)
 
                 # Handle the response
                 print(response)
@@ -1445,7 +1494,12 @@ class FirestoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1466,9 +1520,9 @@ class FirestoreAdminAsyncClient:
 
             from google.cloud import firestore_admin_v1
 
-            def sample_update_database():
+            async def sample_update_database():
                 # Create a client
-                client = firestore_admin_v1.FirestoreAdminClient()
+                client = firestore_admin_v1.FirestoreAdminAsyncClient()
 
                 # Initialize request argument(s)
                 request = firestore_admin_v1.UpdateDatabaseRequest(
@@ -1479,7 +1533,7 @@ class FirestoreAdminAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1550,7 +1604,12 @@ class FirestoreAdminAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
