@@ -261,8 +261,7 @@ class FirestoreAdminGrpcTransport(FirestoreAdminTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -642,5 +641,9 @@ class FirestoreAdminGrpcTransport(FirestoreAdminTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("FirestoreAdminGrpcTransport",)
