@@ -70,12 +70,35 @@ class IndexOperationMetadata(proto.Message):
             The progress, in bytes, of this operation.
     """
 
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    index = proto.Field(proto.STRING, number=3,)
-    state = proto.Field(proto.ENUM, number=4, enum="OperationState",)
-    progress_documents = proto.Field(proto.MESSAGE, number=5, message="Progress",)
-    progress_bytes = proto.Field(proto.MESSAGE, number=6, message="Progress",)
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    index = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=4,
+        enum="OperationState",
+    )
+    progress_documents = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="Progress",
+    )
+    progress_bytes = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="Progress",
+    )
 
 
 class FieldOperationMetadata(proto.Message):
@@ -128,17 +151,46 @@ class FieldOperationMetadata(proto.Message):
             number=1,
             enum="FieldOperationMetadata.IndexConfigDelta.ChangeType",
         )
-        index = proto.Field(proto.MESSAGE, number=2, message=gfa_index.Index,)
+        index = proto.Field(
+            proto.MESSAGE,
+            number=2,
+            message=gfa_index.Index,
+        )
 
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    field = proto.Field(proto.STRING, number=3,)
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    field = proto.Field(
+        proto.STRING,
+        number=3,
+    )
     index_config_deltas = proto.RepeatedField(
-        proto.MESSAGE, number=4, message=IndexConfigDelta,
+        proto.MESSAGE,
+        number=4,
+        message=IndexConfigDelta,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=5,
+        enum="OperationState",
+    )
+    progress_documents = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message="Progress",
+    )
+    progress_bytes = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message="Progress",
     )
-    state = proto.Field(proto.ENUM, number=5, enum="OperationState",)
-    progress_documents = proto.Field(proto.MESSAGE, number=6, message="Progress",)
-    progress_bytes = proto.Field(proto.MESSAGE, number=7, message="Progress",)
 
 
 class ExportDocumentsMetadata(proto.Message):
@@ -166,13 +218,39 @@ class ExportDocumentsMetadata(proto.Message):
             Where the entities are being exported to.
     """
 
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    operation_state = proto.Field(proto.ENUM, number=3, enum="OperationState",)
-    progress_documents = proto.Field(proto.MESSAGE, number=4, message="Progress",)
-    progress_bytes = proto.Field(proto.MESSAGE, number=5, message="Progress",)
-    collection_ids = proto.RepeatedField(proto.STRING, number=6,)
-    output_uri_prefix = proto.Field(proto.STRING, number=7,)
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    operation_state = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum="OperationState",
+    )
+    progress_documents = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="Progress",
+    )
+    progress_bytes = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="Progress",
+    )
+    collection_ids = proto.RepeatedField(
+        proto.STRING,
+        number=6,
+    )
+    output_uri_prefix = proto.Field(
+        proto.STRING,
+        number=7,
+    )
 
 
 class ImportDocumentsMetadata(proto.Message):
@@ -200,13 +278,39 @@ class ImportDocumentsMetadata(proto.Message):
             The location of the documents being imported.
     """
 
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    operation_state = proto.Field(proto.ENUM, number=3, enum="OperationState",)
-    progress_documents = proto.Field(proto.MESSAGE, number=4, message="Progress",)
-    progress_bytes = proto.Field(proto.MESSAGE, number=5, message="Progress",)
-    collection_ids = proto.RepeatedField(proto.STRING, number=6,)
-    input_uri_prefix = proto.Field(proto.STRING, number=7,)
+    start_time = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=timestamp_pb2.Timestamp,
+    )
+    end_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    operation_state = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum="OperationState",
+    )
+    progress_documents = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message="Progress",
+    )
+    progress_bytes = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message="Progress",
+    )
+    collection_ids = proto.RepeatedField(
+        proto.STRING,
+        number=6,
+    )
+    input_uri_prefix = proto.Field(
+        proto.STRING,
+        number=7,
+    )
 
 
 class ExportDocumentsResponse(proto.Message):
@@ -222,7 +326,10 @@ class ExportDocumentsResponse(proto.Message):
             operation completes successfully.
     """
 
-    output_uri_prefix = proto.Field(proto.STRING, number=1,)
+    output_uri_prefix = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class Progress(proto.Message):
@@ -237,8 +344,14 @@ class Progress(proto.Message):
             The amount of work completed.
     """
 
-    estimated_work = proto.Field(proto.INT64, number=1,)
-    completed_work = proto.Field(proto.INT64, number=2,)
+    estimated_work = proto.Field(
+        proto.INT64,
+        number=1,
+    )
+    completed_work = proto.Field(
+        proto.INT64,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
