@@ -3,8 +3,7 @@ from google.cloud.firestore_bundle.types import BundledQuery
 
 
 def limit_type_of_query(query: BaseQuery) -> int:
-    """BundledQuery.LimitType equivalent of this query.
-    """
+    """BundledQuery.LimitType equivalent of this query."""
 
     return (
         BundledQuery.LimitType.LAST
