@@ -234,8 +234,7 @@ class FirestoreGrpcTransport(FirestoreTransport):
 
     @property
     def grpc_channel(self) -> grpc.Channel:
-        """Return the channel designed to connect to this service.
-        """
+        """Return the channel designed to connect to this service."""
         return self._grpc_channel
 
     @property
@@ -647,5 +646,9 @@ class FirestoreGrpcTransport(FirestoreTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("FirestoreGrpcTransport",)
