@@ -91,9 +91,20 @@ class GetDocumentRequest(proto.Message):
             This field is a member of `oneof`_ ``consistency_selector``.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    mask = proto.Field(proto.MESSAGE, number=2, message=common.DocumentMask,)
-    transaction = proto.Field(proto.BYTES, number=3, oneof="consistency_selector",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    mask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=common.DocumentMask,
+    )
+    transaction = proto.Field(
+        proto.BYTES,
+        number=3,
+        oneof="consistency_selector",
+    )
     read_time = proto.Field(
         proto.MESSAGE,
         number=5,
@@ -162,20 +173,46 @@ class ListDocumentsRequest(proto.Message):
             ``order_by``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    collection_id = proto.Field(proto.STRING, number=2,)
-    page_size = proto.Field(proto.INT32, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=6,)
-    mask = proto.Field(proto.MESSAGE, number=7, message=common.DocumentMask,)
-    transaction = proto.Field(proto.BYTES, number=8, oneof="consistency_selector",)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    collection_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    mask = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message=common.DocumentMask,
+    )
+    transaction = proto.Field(
+        proto.BYTES,
+        number=8,
+        oneof="consistency_selector",
+    )
     read_time = proto.Field(
         proto.MESSAGE,
         number=10,
         oneof="consistency_selector",
         message=timestamp_pb2.Timestamp,
     )
-    show_missing = proto.Field(proto.BOOL, number=12,)
+    show_missing = proto.Field(
+        proto.BOOL,
+        number=12,
+    )
 
 
 class ListDocumentsResponse(proto.Message):
@@ -194,9 +231,14 @@ class ListDocumentsResponse(proto.Message):
         return self
 
     documents = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gf_document.Document,
+        proto.MESSAGE,
+        number=1,
+        message=gf_document.Document,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class CreateDocumentRequest(proto.Message):
@@ -227,11 +269,28 @@ class CreateDocumentRequest(proto.Message):
             the response.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    collection_id = proto.Field(proto.STRING, number=2,)
-    document_id = proto.Field(proto.STRING, number=3,)
-    document = proto.Field(proto.MESSAGE, number=4, message=gf_document.Document,)
-    mask = proto.Field(proto.MESSAGE, number=5, message=common.DocumentMask,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    collection_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    document_id = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    document = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=gf_document.Document,
+    )
+    mask = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=common.DocumentMask,
+    )
 
 
 class UpdateDocumentRequest(proto.Message):
@@ -265,11 +324,25 @@ class UpdateDocumentRequest(proto.Message):
             by the target document.
     """
 
-    document = proto.Field(proto.MESSAGE, number=1, message=gf_document.Document,)
-    update_mask = proto.Field(proto.MESSAGE, number=2, message=common.DocumentMask,)
-    mask = proto.Field(proto.MESSAGE, number=3, message=common.DocumentMask,)
+    document = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gf_document.Document,
+    )
+    update_mask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=common.DocumentMask,
+    )
+    mask = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=common.DocumentMask,
+    )
     current_document = proto.Field(
-        proto.MESSAGE, number=4, message=common.Precondition,
+        proto.MESSAGE,
+        number=4,
+        message=common.Precondition,
     )
 
 
@@ -288,9 +361,14 @@ class DeleteDocumentRequest(proto.Message):
             by the target document.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     current_document = proto.Field(
-        proto.MESSAGE, number=2, message=common.Precondition,
+        proto.MESSAGE,
+        number=2,
+        message=common.Precondition,
     )
 
 
@@ -339,10 +417,24 @@ class BatchGetDocumentsRequest(proto.Message):
             This field is a member of `oneof`_ ``consistency_selector``.
     """
 
-    database = proto.Field(proto.STRING, number=1,)
-    documents = proto.RepeatedField(proto.STRING, number=2,)
-    mask = proto.Field(proto.MESSAGE, number=3, message=common.DocumentMask,)
-    transaction = proto.Field(proto.BYTES, number=4, oneof="consistency_selector",)
+    database = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    documents = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+    mask = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=common.DocumentMask,
+    )
+    transaction = proto.Field(
+        proto.BYTES,
+        number=4,
+        oneof="consistency_selector",
+    )
     new_transaction = proto.Field(
         proto.MESSAGE,
         number=5,
@@ -392,11 +484,25 @@ class BatchGetDocumentsResponse(proto.Message):
     """
 
     found = proto.Field(
-        proto.MESSAGE, number=1, oneof="result", message=gf_document.Document,
+        proto.MESSAGE,
+        number=1,
+        oneof="result",
+        message=gf_document.Document,
+    )
+    missing = proto.Field(
+        proto.STRING,
+        number=2,
+        oneof="result",
+    )
+    transaction = proto.Field(
+        proto.BYTES,
+        number=3,
+    )
+    read_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
     )
-    missing = proto.Field(proto.STRING, number=2, oneof="result",)
-    transaction = proto.Field(proto.BYTES, number=3,)
-    read_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
 
 
 class BeginTransactionRequest(proto.Message):
@@ -412,8 +518,15 @@ class BeginTransactionRequest(proto.Message):
             Defaults to a read-write transaction.
     """
 
-    database = proto.Field(proto.STRING, number=1,)
-    options = proto.Field(proto.MESSAGE, number=2, message=common.TransactionOptions,)
+    database = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    options = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=common.TransactionOptions,
+    )
 
 
 class BeginTransactionResponse(proto.Message):
@@ -425,7 +538,10 @@ class BeginTransactionResponse(proto.Message):
             The transaction that was started.
     """
 
-    transaction = proto.Field(proto.BYTES, number=1,)
+    transaction = proto.Field(
+        proto.BYTES,
+        number=1,
+    )
 
 
 class CommitRequest(proto.Message):
@@ -444,9 +560,19 @@ class CommitRequest(proto.Message):
             transaction, and commits it.
     """
 
-    database = proto.Field(proto.STRING, number=1,)
-    writes = proto.RepeatedField(proto.MESSAGE, number=2, message=write.Write,)
-    transaction = proto.Field(proto.BYTES, number=3,)
+    database = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    writes = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message=write.Write,
+    )
+    transaction = proto.Field(
+        proto.BYTES,
+        number=3,
+    )
 
 
 class CommitResponse(proto.Message):
@@ -465,9 +591,15 @@ class CommitResponse(proto.Message):
     """
 
     write_results = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=write.WriteResult,
+        proto.MESSAGE,
+        number=1,
+        message=write.WriteResult,
+    )
+    commit_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
     )
-    commit_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
 
 
 class RollbackRequest(proto.Message):
@@ -482,8 +614,14 @@ class RollbackRequest(proto.Message):
             Required. The transaction to roll back.
     """
 
-    database = proto.Field(proto.STRING, number=1,)
-    transaction = proto.Field(proto.BYTES, number=2,)
+    database = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    transaction = proto.Field(
+        proto.BYTES,
+        number=2,
+    )
 
 
 class RunQueryRequest(proto.Message):
@@ -531,11 +669,21 @@ class RunQueryRequest(proto.Message):
             This field is a member of `oneof`_ ``consistency_selector``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     structured_query = proto.Field(
-        proto.MESSAGE, number=2, oneof="query_type", message=gf_query.StructuredQuery,
+        proto.MESSAGE,
+        number=2,
+        oneof="query_type",
+        message=gf_query.StructuredQuery,
+    )
+    transaction = proto.Field(
+        proto.BYTES,
+        number=5,
+        oneof="consistency_selector",
     )
-    transaction = proto.Field(proto.BYTES, number=5, oneof="consistency_selector",)
     new_transaction = proto.Field(
         proto.MESSAGE,
         number=6,
@@ -554,6 +702,9 @@ class RunQueryResponse(proto.Message):
     r"""The response for
     [Firestore.RunQuery][google.firestore.v1.Firestore.RunQuery].
 
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         transaction (bytes):
             The transaction that was started as part of this request.
@@ -577,12 +728,37 @@ class RunQueryResponse(proto.Message):
             The number of results that have been skipped
             due to an offset between the last response and
             the current response.
+        done (bool):
+            If present, Firestore has completely finished
+            the request and no more documents will be
+            returned.
+
+            This field is a member of `oneof`_ ``continuation_selector``.
     """
 
-    transaction = proto.Field(proto.BYTES, number=2,)
-    document = proto.Field(proto.MESSAGE, number=1, message=gf_document.Document,)
-    read_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    skipped_results = proto.Field(proto.INT32, number=4,)
+    transaction = proto.Field(
+        proto.BYTES,
+        number=2,
+    )
+    document = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gf_document.Document,
+    )
+    read_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    skipped_results = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    done = proto.Field(
+        proto.BOOL,
+        number=6,
+        oneof="continuation_selector",
+    )
 
 
 class PartitionQueryRequest(proto.Message):
@@ -647,13 +823,28 @@ class PartitionQueryRequest(proto.Message):
             ``partition_count``.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     structured_query = proto.Field(
-        proto.MESSAGE, number=2, oneof="query_type", message=gf_query.StructuredQuery,
+        proto.MESSAGE,
+        number=2,
+        oneof="query_type",
+        message=gf_query.StructuredQuery,
+    )
+    partition_count = proto.Field(
+        proto.INT64,
+        number=3,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=5,
     )
-    partition_count = proto.Field(proto.INT64, number=3,)
-    page_token = proto.Field(proto.STRING, number=4,)
-    page_size = proto.Field(proto.INT32, number=5,)
 
 
 class PartitionQueryResponse(proto.Message):
@@ -690,8 +881,15 @@ class PartitionQueryResponse(proto.Message):
     def raw_page(self):
         return self
 
-    partitions = proto.RepeatedField(proto.MESSAGE, number=1, message=gf_query.Cursor,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    partitions = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gf_query.Cursor,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class WriteRequest(proto.Message):
@@ -740,15 +938,32 @@ class WriteRequest(proto.Message):
             ``stream_id`` field.
 
             Leave this field unset when creating a new stream.
-        labels (Sequence[google.cloud.firestore_v1.types.WriteRequest.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels associated with this write request.
     """
 
-    database = proto.Field(proto.STRING, number=1,)
-    stream_id = proto.Field(proto.STRING, number=2,)
-    writes = proto.RepeatedField(proto.MESSAGE, number=3, message=write.Write,)
-    stream_token = proto.Field(proto.BYTES, number=4,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=5,)
+    database = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    stream_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    writes = proto.RepeatedField(
+        proto.MESSAGE,
+        number=3,
+        message=write.Write,
+    )
+    stream_token = proto.Field(
+        proto.BYTES,
+        number=4,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=5,
+    )
 
 
 class WriteResponse(proto.Message):
@@ -775,12 +990,24 @@ class WriteResponse(proto.Message):
             effects of the write.
     """
 
-    stream_id = proto.Field(proto.STRING, number=1,)
-    stream_token = proto.Field(proto.BYTES, number=2,)
+    stream_id = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    stream_token = proto.Field(
+        proto.BYTES,
+        number=2,
+    )
     write_results = proto.RepeatedField(
-        proto.MESSAGE, number=3, message=write.WriteResult,
+        proto.MESSAGE,
+        number=3,
+        message=write.WriteResult,
+    )
+    commit_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
     )
-    commit_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
 
 
 class ListenRequest(proto.Message):
@@ -807,16 +1034,30 @@ class ListenRequest(proto.Message):
             stream.
 
             This field is a member of `oneof`_ ``target_change``.
-        labels (Sequence[google.cloud.firestore_v1.types.ListenRequest.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels associated with this target change.
     """
 
-    database = proto.Field(proto.STRING, number=1,)
+    database = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     add_target = proto.Field(
-        proto.MESSAGE, number=2, oneof="target_change", message="Target",
+        proto.MESSAGE,
+        number=2,
+        oneof="target_change",
+        message="Target",
+    )
+    remove_target = proto.Field(
+        proto.INT32,
+        number=3,
+        oneof="target_change",
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
     )
-    remove_target = proto.Field(proto.INT32, number=3, oneof="target_change",)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
 
 
 class ListenResponse(proto.Message):
@@ -861,19 +1102,34 @@ class ListenResponse(proto.Message):
     """
 
     target_change = proto.Field(
-        proto.MESSAGE, number=2, oneof="response_type", message="TargetChange",
+        proto.MESSAGE,
+        number=2,
+        oneof="response_type",
+        message="TargetChange",
     )
     document_change = proto.Field(
-        proto.MESSAGE, number=3, oneof="response_type", message=write.DocumentChange,
+        proto.MESSAGE,
+        number=3,
+        oneof="response_type",
+        message=write.DocumentChange,
     )
     document_delete = proto.Field(
-        proto.MESSAGE, number=4, oneof="response_type", message=write.DocumentDelete,
+        proto.MESSAGE,
+        number=4,
+        oneof="response_type",
+        message=write.DocumentDelete,
     )
     document_remove = proto.Field(
-        proto.MESSAGE, number=6, oneof="response_type", message=write.DocumentRemove,
+        proto.MESSAGE,
+        number=6,
+        oneof="response_type",
+        message=write.DocumentRemove,
     )
     filter = proto.Field(
-        proto.MESSAGE, number=5, oneof="response_type", message=write.ExistenceFilter,
+        proto.MESSAGE,
+        number=5,
+        oneof="response_type",
+        message=write.ExistenceFilter,
     )
 
 
@@ -934,7 +1190,10 @@ class Target(proto.Message):
                 elided.
         """
 
-        documents = proto.RepeatedField(proto.STRING, number=2,)
+        documents = proto.RepeatedField(
+            proto.STRING,
+            number=2,
+        )
 
     class QueryTarget(proto.Message):
         r"""A target specified by a query.
@@ -956,7 +1215,10 @@ class Target(proto.Message):
                 This field is a member of `oneof`_ ``query_type``.
         """
 
-        parent = proto.Field(proto.STRING, number=1,)
+        parent = proto.Field(
+            proto.STRING,
+            number=1,
+        )
         structured_query = proto.Field(
             proto.MESSAGE,
             number=2,
@@ -965,17 +1227,36 @@ class Target(proto.Message):
         )
 
     query = proto.Field(
-        proto.MESSAGE, number=2, oneof="target_type", message=QueryTarget,
+        proto.MESSAGE,
+        number=2,
+        oneof="target_type",
+        message=QueryTarget,
     )
     documents = proto.Field(
-        proto.MESSAGE, number=3, oneof="target_type", message=DocumentsTarget,
+        proto.MESSAGE,
+        number=3,
+        oneof="target_type",
+        message=DocumentsTarget,
+    )
+    resume_token = proto.Field(
+        proto.BYTES,
+        number=4,
+        oneof="resume_type",
     )
-    resume_token = proto.Field(proto.BYTES, number=4, oneof="resume_type",)
     read_time = proto.Field(
-        proto.MESSAGE, number=11, oneof="resume_type", message=timestamp_pb2.Timestamp,
+        proto.MESSAGE,
+        number=11,
+        oneof="resume_type",
+        message=timestamp_pb2.Timestamp,
+    )
+    target_id = proto.Field(
+        proto.INT32,
+        number=5,
+    )
+    once = proto.Field(
+        proto.BOOL,
+        number=6,
     )
-    target_id = proto.Field(proto.INT32, number=5,)
-    once = proto.Field(proto.BOOL, number=6,)
 
 
 class TargetChange(proto.Message):
@@ -1020,11 +1301,29 @@ class TargetChange(proto.Message):
         CURRENT = 3
         RESET = 4
 
-    target_change_type = proto.Field(proto.ENUM, number=1, enum=TargetChangeType,)
-    target_ids = proto.RepeatedField(proto.INT32, number=2,)
-    cause = proto.Field(proto.MESSAGE, number=3, message=status_pb2.Status,)
-    resume_token = proto.Field(proto.BYTES, number=4,)
-    read_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
+    target_change_type = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=TargetChangeType,
+    )
+    target_ids = proto.RepeatedField(
+        proto.INT32,
+        number=2,
+    )
+    cause = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=status_pb2.Status,
+    )
+    resume_token = proto.Field(
+        proto.BYTES,
+        number=4,
+    )
+    read_time = proto.Field(
+        proto.MESSAGE,
+        number=6,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 class ListCollectionIdsRequest(proto.Message):
@@ -1044,9 +1343,18 @@ class ListCollectionIdsRequest(proto.Message):
             [ListCollectionIdsResponse][google.firestore.v1.ListCollectionIdsResponse].
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
 
 
 class ListCollectionIdsResponse(proto.Message):
@@ -1065,8 +1373,14 @@ class ListCollectionIdsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    collection_ids = proto.RepeatedField(proto.STRING, number=1,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    collection_ids = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class BatchWriteRequest(proto.Message):
@@ -1083,13 +1397,24 @@ class BatchWriteRequest(proto.Message):
             not guarantee ordering. Each write succeeds or
             fails independently. You cannot write to the
             same document more than once per request.
-        labels (Sequence[google.cloud.firestore_v1.types.BatchWriteRequest.LabelsEntry]):
+        labels (Mapping[str, str]):
             Labels associated with this batch write.
     """
 
-    database = proto.Field(proto.STRING, number=1,)
-    writes = proto.RepeatedField(proto.MESSAGE, number=2, message=write.Write,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=3,)
+    database = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    writes = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message=write.Write,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=3,
+    )
 
 
 class BatchWriteResponse(proto.Message):
@@ -1108,9 +1433,15 @@ class BatchWriteResponse(proto.Message):
     """
 
     write_results = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=write.WriteResult,
+        proto.MESSAGE,
+        number=1,
+        message=write.WriteResult,
+    )
+    status = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message=status_pb2.Status,
     )
-    status = proto.RepeatedField(proto.MESSAGE, number=2, message=status_pb2.Status,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
