@@ -20,7 +20,11 @@ from google.protobuf import wrappers_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
-    package="google.firestore.v1", manifest={"StructuredQuery", "Cursor",},
+    package="google.firestore.v1",
+    manifest={
+        "StructuredQuery",
+        "Cursor",
+    },
 )
 
 
@@ -90,8 +94,14 @@ class StructuredQuery(proto.Message):
                 collections.
         """
 
-        collection_id = proto.Field(proto.STRING, number=2,)
-        all_descendants = proto.Field(proto.BOOL, number=3,)
+        collection_id = proto.Field(
+            proto.STRING,
+            number=2,
+        )
+        all_descendants = proto.Field(
+            proto.BOOL,
+            number=3,
+        )
 
     class Filter(proto.Message):
         r"""A filter.
@@ -146,7 +156,10 @@ class StructuredQuery(proto.Message):
                 The operator for combining multiple filters.
             filters (Sequence[google.cloud.firestore_v1.types.StructuredQuery.Filter]):
                 The list of filters to combine.
-                Must contain at least one filter.
+
+                Requires:
+
+                -  At least one filter is present.
         """
 
         class Operator(proto.Enum):
@@ -155,10 +168,14 @@ class StructuredQuery(proto.Message):
             AND = 1
 
         op = proto.Field(
-            proto.ENUM, number=1, enum="StructuredQuery.CompositeFilter.Operator",
+            proto.ENUM,
+            number=1,
+            enum="StructuredQuery.CompositeFilter.Operator",
         )
         filters = proto.RepeatedField(
-            proto.MESSAGE, number=2, message="StructuredQuery.Filter",
+            proto.MESSAGE,
+            number=2,
+            message="StructuredQuery.Filter",
         )
 
     class FieldFilter(proto.Message):
@@ -188,12 +205,20 @@ class StructuredQuery(proto.Message):
             NOT_IN = 10
 
         field = proto.Field(
-            proto.MESSAGE, number=1, message="StructuredQuery.FieldReference",
+            proto.MESSAGE,
+            number=1,
+            message="StructuredQuery.FieldReference",
         )
         op = proto.Field(
-            proto.ENUM, number=2, enum="StructuredQuery.FieldFilter.Operator",
+            proto.ENUM,
+            number=2,
+            enum="StructuredQuery.FieldFilter.Operator",
+        )
+        value = proto.Field(
+            proto.MESSAGE,
+            number=3,
+            message=document.Value,
         )
-        value = proto.Field(proto.MESSAGE, number=3, message=document.Value,)
 
     class UnaryFilter(proto.Message):
         r"""A filter with a single operand.
@@ -218,7 +243,9 @@ class StructuredQuery(proto.Message):
             IS_NOT_NULL = 5
 
         op = proto.Field(
-            proto.ENUM, number=1, enum="StructuredQuery.UnaryFilter.Operator",
+            proto.ENUM,
+            number=1,
+            enum="StructuredQuery.UnaryFilter.Operator",
         )
         field = proto.Field(
             proto.MESSAGE,
@@ -238,9 +265,15 @@ class StructuredQuery(proto.Message):
         """
 
         field = proto.Field(
-            proto.MESSAGE, number=1, message="StructuredQuery.FieldReference",
+            proto.MESSAGE,
+            number=1,
+            message="StructuredQuery.FieldReference",
+        )
+        direction = proto.Field(
+            proto.ENUM,
+            number=2,
+            enum="StructuredQuery.Direction",
         )
-        direction = proto.Field(proto.ENUM, number=2, enum="StructuredQuery.Direction",)
 
     class FieldReference(proto.Message):
         r"""A reference to a field, such as ``max(messages.time) as max_time``.
@@ -250,7 +283,10 @@ class StructuredQuery(proto.Message):
 
         """
 
-        field_path = proto.Field(proto.STRING, number=2,)
+        field_path = proto.Field(
+            proto.STRING,
+            number=2,
+        )
 
     class Projection(proto.Message):
         r"""The projection of document's fields to return.
@@ -264,17 +300,50 @@ class StructuredQuery(proto.Message):
         """
 
         fields = proto.RepeatedField(
-            proto.MESSAGE, number=2, message="StructuredQuery.FieldReference",
+            proto.MESSAGE,
+            number=2,
+            message="StructuredQuery.FieldReference",
         )
 
-    select = proto.Field(proto.MESSAGE, number=1, message=Projection,)
-    from_ = proto.RepeatedField(proto.MESSAGE, number=2, message=CollectionSelector,)
-    where = proto.Field(proto.MESSAGE, number=3, message=Filter,)
-    order_by = proto.RepeatedField(proto.MESSAGE, number=4, message=Order,)
-    start_at = proto.Field(proto.MESSAGE, number=7, message="Cursor",)
-    end_at = proto.Field(proto.MESSAGE, number=8, message="Cursor",)
-    offset = proto.Field(proto.INT32, number=6,)
-    limit = proto.Field(proto.MESSAGE, number=5, message=wrappers_pb2.Int32Value,)
+    select = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=Projection,
+    )
+    from_ = proto.RepeatedField(
+        proto.MESSAGE,
+        number=2,
+        message=CollectionSelector,
+    )
+    where = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=Filter,
+    )
+    order_by = proto.RepeatedField(
+        proto.MESSAGE,
+        number=4,
+        message=Order,
+    )
+    start_at = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message="Cursor",
+    )
+    end_at = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message="Cursor",
+    )
+    offset = proto.Field(
+        proto.INT32,
+        number=6,
+    )
+    limit = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=wrappers_pb2.Int32Value,
+    )
 
 
 class Cursor(proto.Message):
@@ -293,8 +362,15 @@ class Cursor(proto.Message):
             defined by the query.
     """
 
-    values = proto.RepeatedField(proto.MESSAGE, number=1, message=document.Value,)
-    before = proto.Field(proto.BOOL, number=2,)
+    values = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=document.Value,
+    )
+    before = proto.Field(
+        proto.BOOL,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
