@@ -922,6 +922,9 @@ def test_collection_group_queries_filters(client, cleanup):
     assert found == set(["cg-doc2"])
 
 
+@pytest.mark.skipif(
+    FIRESTORE_EMULATOR, reason="PartitionQuery not implemented in emulator"
+)
 def test_partition_query_no_partitions(client, cleanup):
     collection_group = "b" + UNIQUE_RESOURCE_ID
 
@@ -953,6 +956,9 @@ def test_partition_query_no_partitions(client, cleanup):
     assert found == expected
 
 
+@pytest.mark.skipif(
+    FIRESTORE_EMULATOR, reason="PartitionQuery not implemented in emulator"
+)
 def test_partition_query(client, cleanup):
     collection_group = "b" + UNIQUE_RESOURCE_ID
     n_docs = 128 * 2 + 127  # Minimum partition size is 128
@@ -1319,19 +1325,24 @@ philosophers_data_set = [
 ]
 
 
-def _do_recursive_delete_with_bulk_writer(client, bulk_writer):
-    philosophers = [philosophers_data_set[0]]
-    _persist_documents(client, f"philosophers{UNIQUE_RESOURCE_ID}", philosophers)
+def _do_recursive_delete(client, bulk_writer, empty_philosophers=False):
 
-    doc_paths = [
-        "",
-        "/pets/Scruffy",
-        "/pets/Snowflake",
-        "/hobbies/pontificating",
-        "/hobbies/journaling",
-        "/philosophers/Aristotle",
-        "/philosophers/Plato",
-    ]
+    if empty_philosophers:
+        doc_paths = philosophers = []
+    else:
+        philosophers = [philosophers_data_set[0]]
+
+        doc_paths = [
+            "",
+            "/pets/Scruffy",
+            "/pets/Snowflake",
+            "/hobbies/pontificating",
+            "/hobbies/journaling",
+            "/philosophers/Aristotle",
+            "/philosophers/Plato",
+        ]
+
+    _persist_documents(client, f"philosophers{UNIQUE_RESOURCE_ID}", philosophers)
 
     # Assert all documents were created so that when they're missing after the
     # delete, we're actually testing something.
@@ -1356,14 +1367,28 @@ def test_recursive_delete_parallelized(client, cleanup):
     from google.cloud.firestore_v1.bulk_writer import BulkWriterOptions, SendMode
 
     bw = client.bulk_writer(options=BulkWriterOptions(mode=SendMode.parallel))
-    _do_recursive_delete_with_bulk_writer(client, bw)
+    _do_recursive_delete(client, bw)
 
 
 def test_recursive_delete_serialized(client, cleanup):
     from google.cloud.firestore_v1.bulk_writer import BulkWriterOptions, SendMode
 
     bw = client.bulk_writer(options=BulkWriterOptions(mode=SendMode.serial))
-    _do_recursive_delete_with_bulk_writer(client, bw)
+    _do_recursive_delete(client, bw)
+
+
+def test_recursive_delete_parallelized_empty(client, cleanup):
+    from google.cloud.firestore_v1.bulk_writer import BulkWriterOptions, SendMode
+
+    bw = client.bulk_writer(options=BulkWriterOptions(mode=SendMode.parallel))
+    _do_recursive_delete(client, bw, empty_philosophers=True)
+
+
+def test_recursive_delete_serialized_empty(client, cleanup):
+    from google.cloud.firestore_v1.bulk_writer import BulkWriterOptions, SendMode
+
+    bw = client.bulk_writer(options=BulkWriterOptions(mode=SendMode.serial))
+    _do_recursive_delete(client, bw, empty_philosophers=True)
 
 
 def test_recursive_query(client, cleanup):
@@ -1514,11 +1539,14 @@ def test_watch_query_order(client, cleanup):
     # Setup listener
     def on_snapshot(docs, changes, read_time):
         try:
+            docs = [i for i in docs if i.id.endswith(UNIQUE_RESOURCE_ID)]
             if len(docs) != 5:
                 return
             # A snapshot should return the same thing as if a query ran now.
             query_ran = query_ref.stream()
-            query_ran_results = [i for i in query_ran]
+            query_ran_results = [
+                i for i in query_ran if i.id.endswith(UNIQUE_RESOURCE_ID)
+            ]
             assert len(docs) == len(query_ran_results)
 
             # compare the order things are returned
@@ -1568,3 +1596,40 @@ def test_watch_query_order(client, cleanup):
         raise AssertionError(
             "5 docs expected in snapshot method " + str(on_snapshot.last_doc_count)
         )
+
+
+def test_repro_429(client, cleanup):
+    # See: https://github.com/googleapis/python-firestore/issues/429
+    now = datetime.datetime.utcnow().replace(tzinfo=UTC)
+    collection = client.collection("repro-429" + UNIQUE_RESOURCE_ID)
+
+    for document_id in [f"doc-{doc_id:02d}" for doc_id in range(30)]:
+        data = {"now": now, "paymentId": None}
+        _, document = collection.add(data, document_id)
+        cleanup(document.delete)
+
+    query = collection.where("paymentId", "==", None).limit(10).order_by("__name__")
+
+    last_snapshot = None
+    for snapshot in query.stream():
+        print(f"id: {snapshot.id}")
+        last_snapshot = snapshot
+
+    query2 = query.start_after(last_snapshot)
+
+    for snapshot in query2.stream():
+        print(f"id: {snapshot.id}")
+
+
+def test_repro_391(client, cleanup):
+    # See: https://github.com/googleapis/python-firestore/issues/391
+    now = datetime.datetime.utcnow().replace(tzinfo=UTC)
+    collection = client.collection("repro-391" + UNIQUE_RESOURCE_ID)
+
+    document_ids = [f"doc-{doc_id:02d}" for doc_id in range(30)]
+
+    for document_id in [f"doc-{doc_id:02d}" for doc_id in range(30)]:
+        data = {"now": now}
+        _, document = collection.add(data, document_id)
+
+    assert len(set(collection.stream())) == len(document_ids)
