@@ -17,6 +17,7 @@ import datetime
 import itertools
 import math
 import pytest
+import pytest_asyncio
 import operator
 from typing import Callable, Dict, List, Optional
 
@@ -40,7 +41,6 @@ from tests.system.test__helpers import (
     FIRESTORE_EMULATOR,
 )
 
-_test_event_loop = asyncio.new_event_loop()
 pytestmark = pytest.mark.asyncio
 
 
@@ -62,7 +62,7 @@ def client():
     yield firestore.AsyncClient(project=project, credentials=credentials)
 
 
-@pytest.fixture
+@pytest_asyncio.fixture
 async def cleanup():
     operations = []
     yield operations.append
@@ -71,10 +71,13 @@ async def cleanup():
         await operation()
 
 
-@pytest.fixture
+@pytest.fixture(scope="module")
 def event_loop():
-    asyncio.set_event_loop(_test_event_loop)
-    return asyncio.get_event_loop()
+    """Change event_loop fixture to module level."""
+    policy = asyncio.get_event_loop_policy()
+    loop = policy.new_event_loop()
+    yield loop
+    loop.close()
 
 
 async def test_collections(client):
@@ -546,7 +549,7 @@ async def test_collection_add(client, cleanup):
     assert set([i async for i in collection3.list_documents()]) == {document_ref5}
 
 
-@pytest.fixture
+@pytest_asyncio.fixture
 async def query_docs(client):
     collection_id = "qs" + UNIQUE_RESOURCE_ID
     sub_collection = "child" + UNIQUE_RESOURCE_ID
@@ -917,6 +920,9 @@ async def test_collection_group_queries_filters(client, cleanup):
     assert found == set(["cg-doc2"])
 
 
+@pytest.mark.skipif(
+    FIRESTORE_EMULATOR, reason="PartitionQuery not implemented in emulator"
+)
 async def test_partition_query_no_partitions(client, cleanup):
     collection_group = "b" + UNIQUE_RESOURCE_ID
 
@@ -947,6 +953,9 @@ async def test_partition_query_no_partitions(client, cleanup):
     assert found == expected
 
 
+@pytest.mark.skipif(
+    FIRESTORE_EMULATOR, reason="PartitionQuery not implemented in emulator"
+)
 async def test_partition_query(client, cleanup):
     collection_group = "b" + UNIQUE_RESOURCE_ID
     n_docs = 128 * 2 + 127  # Minimum partition size is 128
@@ -1178,22 +1187,26 @@ philosophers_data_set = [
 ]
 
 
-async def _do_recursive_delete_with_bulk_writer(client, bulk_writer):
-    philosophers = [philosophers_data_set[0]]
+async def _do_recursive_delete(client, bulk_writer, empty_philosophers=False):
+
+    if empty_philosophers:
+        philosophers = doc_paths = []
+    else:
+        philosophers = [philosophers_data_set[0]]
+        doc_paths = [
+            "",
+            "/pets/Scruffy",
+            "/pets/Snowflake",
+            "/hobbies/pontificating",
+            "/hobbies/journaling",
+            "/philosophers/Aristotle",
+            "/philosophers/Plato",
+        ]
+
     await _persist_documents(
         client, f"philosophers-async{UNIQUE_RESOURCE_ID}", philosophers
     )
 
-    doc_paths = [
-        "",
-        "/pets/Scruffy",
-        "/pets/Snowflake",
-        "/hobbies/pontificating",
-        "/hobbies/journaling",
-        "/philosophers/Aristotle",
-        "/philosophers/Plato",
-    ]
-
     # Assert all documents were created so that when they're missing after the
     # delete, we're actually testing something.
     collection_ref = client.collection(f"philosophers-async{UNIQUE_RESOURCE_ID}")
@@ -1217,14 +1230,28 @@ async def test_async_recursive_delete_parallelized(client, cleanup):
     from google.cloud.firestore_v1.bulk_writer import BulkWriterOptions, SendMode
 
     bw = client.bulk_writer(options=BulkWriterOptions(mode=SendMode.parallel))
-    await _do_recursive_delete_with_bulk_writer(client, bw)
+    await _do_recursive_delete(client, bw)
 
 
 async def test_async_recursive_delete_serialized(client, cleanup):
     from google.cloud.firestore_v1.bulk_writer import BulkWriterOptions, SendMode
 
     bw = client.bulk_writer(options=BulkWriterOptions(mode=SendMode.serial))
-    await _do_recursive_delete_with_bulk_writer(client, bw)
+    await _do_recursive_delete(client, bw)
+
+
+async def test_async_recursive_delete_parallelized_empty(client, cleanup):
+    from google.cloud.firestore_v1.bulk_writer import BulkWriterOptions, SendMode
+
+    bw = client.bulk_writer(options=BulkWriterOptions(mode=SendMode.parallel))
+    await _do_recursive_delete(client, bw, empty_philosophers=True)
+
+
+async def test_async_recursive_delete_serialized_empty(client, cleanup):
+    from google.cloud.firestore_v1.bulk_writer import BulkWriterOptions, SendMode
+
+    bw = client.bulk_writer(options=BulkWriterOptions(mode=SendMode.serial))
+    await _do_recursive_delete(client, bw, empty_philosophers=True)
 
 
 async def test_recursive_query(client, cleanup):
